@@ -20,11 +20,10 @@ def trimesh_smooth_laplacian_cotangent(trimesh, fixed, kmax=10):
 
     """
     for k in range(kmax):
-        V = array(trimesh.get_vertices_attributes('xyz'))
+        V = array(trimesh.vertices_attributes('xyz'))
         L = trimesh_cotangent_laplacian_matrix(trimesh)
         d = L.dot(V)
         V = V + d
-
         for key, attr in trimesh.vertices(True):
             if key in fixed:
                 continue
