@@ -4,10 +4,10 @@ from __future__ import print_function
 
 import compas
 
-from .dr import *
+from .dr import *  # noqa: F401 F403
 
 if not compas.IPY:
-    from .dr_numpy import *
+    from .dr_numpy import *  # noqa: F401 F403
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
