@@ -5,6 +5,14 @@ compas_ghpython.geometry
 
 .. currentmodule:: compas_ghpython.geometry
 
+.. autosummary::
+
+    :toctree: generated/
+    xform_from_transformation
+    xform_from_transformation_matrix
+    xtransform
+    xtransformed
+
 """
 from __future__ import absolute_import
 
